import React, {useEffect, useState} from 'react'
import '@material/web/textfield/outlined-text-field'
import '@material/web/fab/fab'
import '@material/web/icon/icon'
import '@material/web/select/outlined-select'
import '@material/web/select/select-option'
import '@material/web/iconbutton/icon-button'
import '@material/web/checkbox/checkbox'

import PollListItem from '../components/PollListItem'
import FullScreenDialog from '../components/FullScreenDialog'
import Card from '../components/Card'

import './PollsScreen.css'

const PollContext = React.createContext({
    polls: [],
    fetchPolls: () => {},
})

const apiUrl = new URL(window.location)
apiUrl.pathname = '/api/polls'

export default function PollsScreen() {
    const [polls, setPolls] = useState([])
    const [editPoll, setEditPoll] = useState(false)

    const fetchPolls = async () => {
        const response = await fetch('/api/polls')
        const polls = await response.json()
        setPolls(polls)
    }

    const updatePoll = async (poll) => {
        await fetch(apiUrl, {
            method: 'PUT',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify(poll)
        })
        await fetchPolls()
    }

    useEffect(() => {
        fetchPolls()
    }, [])

    return (
        <section id="polls-screen">

            <md-list>
                <PollContext.Provider value={{polls, fetchPolls}}>
                    {polls.map((poll) => (
                        PollListItem(poll, setEditPoll, updatePoll)
                    ))}
                </PollContext.Provider>
            </md-list>

            <FullScreenDialog
                classList={`poll-edit ${editPoll ? 'open' : 'close'}`}
                setEditPoll={setEditPoll}>

                <md-outlined-text-field
                        label="Название"
                        value={editPoll ? editPoll.name : ''}
                        supporting-text="Отображается в списке опросов"
                        required="required">
                    <md-icon slot="leading-icon">title</md-icon>
                </md-outlined-text-field>

                <md-outlined-select label="Дни недели" required="required">

                    <md-icon slot="leading-icon">date_range</md-icon>

                    <md-select-option value="mon">
                        <div slot="headline">Понедельник</div>
                    </md-select-option>

                    <md-select-option value="tue">
                        <div slot="headline">Вторник</div>
                    </md-select-option>

                    <md-select-option value="wed">
                        <div slot="headline">Среда</div>
                    </md-select-option>

                    <md-select-option value="thu">
                        <div slot="headline">Четверг</div>
                    </md-select-option>

                    <md-select-option value="fri">
                        <div slot="headline">Пятница</div>
                    </md-select-option>

                    <md-select-option value="sat">
                        <div slot="headline">Суббота</div>
                    </md-select-option>

                    <md-select-option value="sun">
                        <div slot="headline">Воскресенье</div>
                    </md-select-option>

                </md-outlined-select>

                <section id="poll-messages">

                    <div className="messages-title md-typescale-title-medium">Сообщения</div>

                    <Card>

                        <div className="title md-typescale-title-small">Общее</div>

                        <md-outlined-text-field
                            label="Название"
                            value=""
                            supporting-text="Позволяет идентифицировать сообщение"
                            required="required">
                            <md-icon slot="leading-icon">title</md-icon>
                        </md-outlined-text-field>

                        <md-outlined-text-field
                            label="Время начала"
                            value=""
                            supporting-text="Время отправки сообщения"
                            required="required">
                            <md-icon slot="leading-icon">title</md-icon>
                        </md-outlined-text-field>

                        <md-outlined-text-field
                            label="Время окончания"
                            value=""
                            supporting-text="Время прекращения обработки событий"
                            required="required">
                            <md-icon slot="leading-icon">title</md-icon>
                        </md-outlined-text-field>

                        <div>
                            <label className="md-typescale-body-large">
                                <md-checkbox touch-target="wrapper"></md-checkbox>
                                Не отправлять уведомление
                            </label>

                            <label className="md-typescale-body-large">
                                <md-checkbox touch-target="wrapper"></md-checkbox>
                                Удалить после окончания
                            </label>
                        </div>

                        <md-outlined-select label="Тип" value="poll" required="required">

                            <md-icon slot="leading-icon">attach_file</md-icon>

                            <md-select-option value="text">
                                <div slot="headline">Текст</div>
                            </md-select-option>

                            <md-select-option value="poll">
                                <div slot="headline">Опрос</div>
                            </md-select-option>

                            <md-select-option value="image">
                                <div slot="headline">Изображение</div>
                            </md-select-option>

                            <md-select-option value="video">
                                <div slot="headline">Видео</div>
                            </md-select-option>

                            <md-select-option value="audio">
                                <div slot="headline">Аудио</div>
                            </md-select-option>

                            <md-select-option value="file">
                                <div slot="headline">Файл</div>
                            </md-select-option>

                        </md-outlined-select>

                        <div className="title md-typescale-title-small">Опрос</div>

                        <md-outlined-text-field
                            label="Вопрос"
                            value=""
                            required="required">
                            <md-icon slot="leading-icon">contact_support</md-icon>
                        </md-outlined-text-field>

                        <div className="title md-typescale-label-medium">Варианты ответа</div>

                        <div className="poll-options">

                            <div className="poll-option">
                                <md-outlined-text-field
                                    class="option-text"
                                    label="Добавить ответ"
                                    value=""
                                    required="required"/>
                                <md-icon-button class="option-action">
                                    <md-icon>adjust</md-icon>
                                </md-icon-button>
                            </div>

                        </div>

                        <div className="title md-typescale-title-small">Настройки</div>

                        <div>
                            <label className="md-typescale-body-large">
                                <md-checkbox touch-target="wrapper"></md-checkbox>
                                Анонимное голосование
                            </label>

                            <label className="md-typescale-body-large">
                                <md-checkbox touch-target="wrapper"></md-checkbox>
                                Выбор нескольких ответов
                            </label>
                        </div>

                    </Card>

                </section>

            </FullScreenDialog>

        </section>
    )
}
